powered by
Download Whisper model weights and tokenizer files from HuggingFace. In interactive sessions, asks for user consent before downloading.
download_whisper_model(model = "tiny", force = FALSE)
Path to model directory (invisibly)
Model name: "tiny", "base", "small", "medium", "large-v3"
Re-download even if exists
# \donttest{ if (interactive()) { # Download tiny model (smallest, ~150MB) download_whisper_model("tiny") # Download larger model for better accuracy download_whisper_model("small") } # }
Run the code above in your browser using DataLab